@@ -3,9 +3,8 @@
 
 """Test Hdfs client interactions with HDFS."""
 
-from hdfs import KerberosClient
-from hdfs.client import HdfsError, Client
-from hdfs.util import Config, temppath
+from hdfs.client import *
+from hdfs.util import HdfsError, temppath
 from helpers import _TestSession
 from nose.tools import eq_, ok_, raises
 from shutil import rmtree
@@ -28,10 +27,6 @@ class TestLoad(object):
     client = Client._from_options(None, {'url': 'foo'})
     ok_(isinstance(client, Client))
 
-  def test_kerberos(self):
-    client = Client._from_options('KerberosClient', {'url': 'foo'})
-    ok_(isinstance(client, KerberosClient))
-
   def test_new_type(self):
     class NewClient(Client):
       def __init__(self, url, bar):
